@@ -32,12 +32,17 @@
  *
  * #PeasActivatable is an interface which should be implemented by extensions
  * that should be activated on an object of a certain type (depending on the
- * application). For instance, in gedit, #PeasActivatable extension instances
- * are bound to individual windows.
+ * application). For instance, in a typical windowed application,
+ * #PeasActivatable extension instances could be bound to individual toplevel
+ * windows.
  *
  * It is typical to use #PeasActivatable along with #PeasExtensionSet in order
  * to activate and deactivate extensions automatically when plugins are loaded
- * or unloaded. 
+ * or unloaded.
+ *
+ * You can also use the code of this interface as a base for your own
+ * extension types, as illustrated by gedit's #GeditWindowActivatable and
+ * #GeditDocumentActivatable interfaces.
  **/
 
 G_DEFINE_INTERFACE(PeasActivatable, peas_activatable, G_TYPE_OBJECT)
@@ -45,69 +50,89 @@ G_DEFINE_INTERFACE(PeasActivatable, peas_activatable, G_TYPE_OBJECT)
 void
 peas_activatable_default_init (PeasActivatableInterface *iface)
 {
+  static gboolean initialized = FALSE;
+
+  if (!initialized)
+    {
+      /**
+       * PeasActivatable:object:
+       *
+       * The object property contains the targetted object for this
+       * #PeasActivatable instance, for example a toplevel window in a typical
+       * windowed application. It is set at construction time and won't change.
+       */
+      g_object_interface_install_property (iface,
+                                           g_param_spec_object ("object",
+                                                                "Object",
+                                                                "Object",
+                                                                G_TYPE_OBJECT,
+                                                                G_PARAM_READWRITE |
+                                                                G_PARAM_CONSTRUCT_ONLY |
+                                                                G_PARAM_STATIC_STRINGS));
+
+      initialized = TRUE;
+    }
 }
 
 /**
  * peas_activatable_activate:
  * @activatable: A #PeasActivatable.
- * @object: The #GObject on which the plugin should be activated.
  *
- * Activates the extension on the given object.
+ * Activates the extension on the targetted object.
+ *
+ * On activation, the extension should hook itself to the object
+ * where it makes sense.
  */
 void
-peas_activatable_activate (PeasActivatable *activatable,
-                           GObject         *object)
+peas_activatable_activate (PeasActivatable *activatable)
 {
   PeasActivatableInterface *iface;
 
   g_return_if_fail (PEAS_IS_ACTIVATABLE (activatable));
-  g_return_if_fail (G_IS_OBJECT (object));
 
   iface = PEAS_ACTIVATABLE_GET_IFACE (activatable);
   if (iface->activate != NULL)
-    iface->activate (activatable, object);
+    iface->activate (activatable);
 }
 
 /**
  * peas_activatable_deactivate:
  * @activatable: A #PeasActivatable.
- * @object: A #GObject.
  *
- * Deactivates the plugin on the given object.
+ * Deactivates the extension on the targetted object.
+ *
+ * On deactivation, an extension should remove itself from all the hooks it
+ * used and should perform any cleanup required, so it can be unreffed safely
+ * and without any more effect on the host application.
  */
 void
-peas_activatable_deactivate (PeasActivatable *activatable,
-                             GObject         *object)
+peas_activatable_deactivate (PeasActivatable *activatable)
 {
   PeasActivatableInterface *iface;
 
   g_return_if_fail (PEAS_IS_ACTIVATABLE (activatable));
-  g_return_if_fail (G_IS_OBJECT (object));
 
   iface = PEAS_ACTIVATABLE_GET_IFACE (activatable);
   if (iface->deactivate != NULL)
-    iface->deactivate (activatable, object);
+    iface->deactivate (activatable);
 }
 
 /**
  * peas_activatable_update_state:
  * @activatable: A #PeasActivatable.
- * @object: A #GObject.
  *
- * Triggers an update of the plugin's internal state to take into account
- * state changes in the targetted object, due to a plugin or user action.
+ * Triggers an update of the extension internal state to take into account
+ * state changes in the targetted object, due to some event or user action.
  */
 void
-peas_activatable_update_state (PeasActivatable *activatable,
-                               GObject         *object)
+peas_activatable_update_state (PeasActivatable *activatable)
 {
   PeasActivatableInterface *iface;
 
   g_return_if_fail (PEAS_IS_ACTIVATABLE (activatable));
-  g_return_if_fail (G_IS_OBJECT (object));
 
   iface = PEAS_ACTIVATABLE_GET_IFACE (activatable);
   if (iface->update_state != NULL)
-    iface->update_state (activatable, object);
+    iface->update_state (activatable);
 }
 
